@@ -1,15 +1,9 @@
+use crate::lex_states::*;
 use crate::lexer::*;
 use crate::maybe_byte::*;
 use crate::reserved_word;
 use crate::source::buffer::*;
 use crate::DiagnosticMessage;
-use crate::{lex_states::*, LexState};
-
-pub(crate) trait ParseIdent {
-    fn is_identchar(&self) -> bool;
-    fn tokenize_ident(&mut self) -> Option<String>;
-    fn parse_ident(&mut self, c: &MaybeByte, cmd_state: bool) -> i32;
-}
 
 fn is_var_name(ident: &str) -> bool {
     if let Some(first_char) = ident.chars().next() {
@@ -18,28 +12,27 @@ fn is_var_name(ident: &str) -> bool {
     false
 }
 
-impl ParseIdent for Lexer {
-    fn is_identchar(&self) -> bool {
+impl Lexer {
+    pub(crate) fn is_identchar(&self) -> bool {
         !self.buffer.eofp
             && self
                 .buffer
                 .is_identchar(self.buffer.pcur - 1, self.buffer.pend)
     }
 
-    fn tokenize_ident(&mut self) -> Option<String> {
+    pub(crate) fn tokenize_ident(&mut self) -> Option<String> {
         self.set_yylval_name();
         self.tokenbuf.borrow_string().map(|s| s.to_string()).ok()
     }
 
-    fn parse_ident(&mut self, c: &MaybeByte, cmd_state: bool) -> i32 {
-        let mut c = c.clone();
+    pub(crate) fn parse_ident(&mut self, mut c: MaybeByte, cmd_state: bool) -> i32 {
         let mut result: i32;
-        let last_state: LexState = self.lex_state.clone();
+        let last_state = self.lex_state;
         let ident: String;
 
         loop {
             if !c.is_ascii() { /* mb = ENC_CODERANGE_UNKNOWN */ }
-            if self.tokadd_mbchar(&c).is_err() {
+            if self.tokadd_mbchar(c).is_err() {
                 return Self::END_OF_INPUT;
             }
             c = self.nextc();
@@ -51,7 +44,7 @@ impl ParseIdent for Lexer {
 
         if (c == b'!' || c == b'?') && !self.buffer.peek(b'=') {
             result = Self::tFID;
-            self.tokadd(&c);
+            self.tokadd(c);
         } else if c == b'='
             && self.lex_state.is_some(EXPR_FNAME)
             && (!self.buffer.peek(b'~')
@@ -59,10 +52,10 @@ impl ParseIdent for Lexer {
                 && (!self.buffer.peek(b'=') || (self.buffer.peek_n(b'>', 1))))
         {
             result = Self::tIDENTIFIER;
-            self.tokadd(&c)
+            self.tokadd(c)
         } else {
             result = Self::tCONSTANT; /* assume provisionally */
-            self.buffer.pushback(&c)
+            self.buffer.pushback(c)
         }
         self.tokfix();
 
@@ -74,7 +67,7 @@ impl ParseIdent for Lexer {
         }
         if !self.lex_state.is_some(EXPR_DOT) {
             if let Some(kw) = reserved_word(self.tokenbuf.bytes.as_raw()) {
-                let state: LexState = self.lex_state.clone();
+                let state = self.lex_state;
                 if state.is_some(EXPR_FNAME) {
                     self.lex_state.set(EXPR_ENDFN);
                     self.set_yylval_name();
